pub struct EntityRegistryLock(OnceLock<EntityRegistry>);Expand description
Wrapper for the global entity registry that implements Deref.
Tuple Fields
0: OnceLock<EntityRegistry>Implementations
Sourceimpl EntityRegistryLock
impl EntityRegistryLock
Sourcepub fn set(&self, registry: EntityRegistry) -> Result<(), EntityRegistry>
pub fn set(&self, registry: EntityRegistry) -> Result<(), EntityRegistry>
Sets the registry. Returns Err if already initialized.
fn get_or_init(&self, init: impl FnOnce() -> EntityRegistry) -> &EntityRegistry
Sourcepub fn get(&self) -> Option<&EntityRegistry>
pub fn get(&self) -> Option<&EntityRegistry>
Returns the initialized registry, if entity factories have been installed.
Methods from Deref<Target = EntityRegistry>
Sourcepub fn create(
&self,
entity_type: EntityTypeRef,
entity_id: i32,
pos: DVec3,
world: Weak<World>,
) -> Option<SharedEntity>
pub fn create( &self, entity_type: EntityTypeRef, entity_id: i32, pos: DVec3, world: Weak<World>, ) -> Option<SharedEntity>
Creates a new entity instance.
Returns None if no factory is registered for the given type.
Sourcepub fn create_and_load_or_raw(
&self,
request: EntityLoadRequest,
nbt: &BorrowedNbtCompound<'_>,
) -> SharedEntity
pub fn create_and_load_or_raw( &self, request: EntityLoadRequest, nbt: &BorrowedNbtCompound<'_>, ) -> SharedEntity
Creates an entity from persisted data, falling back to raw NBT preservation.
Sourcepub fn has_factory(&self, entity_type: EntityTypeRef) -> bool
pub fn has_factory(&self, entity_type: EntityTypeRef) -> bool
Returns whether a factory is registered for the given type.